Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/applicant.py	(revision 7321)
@@ -24,5 +24,5 @@
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
 from waeup.sirp.app import University
-from waeup.sirp.image import WAeUPImageFile
+from waeup.sirp.image import SIRPImageFile
 from waeup.sirp.imagestorage import DefaultFileStoreHandler
 from waeup.sirp.interfaces import (
@@ -220,5 +220,5 @@
             ApplicantImageStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, WAeUPImageFile(
+        return file, path, SIRPImageFile(
             file_obj.filename, file_obj.data)
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/interfaces.py	(revision 7321)
@@ -30,5 +30,5 @@
 from waeup.sirp.schema import TextLineChoice
 from waeup.sirp.interfaces import (
-    IWAeUPObject, year_range, validate_email, academic_sessions_vocab)
+    ISIRPObject, year_range, validate_email, academic_sessions_vocab)
 from waeup.sirp.university.vocabularies import application_categories
 from waeup.sirp.students.vocabularies import (
@@ -118,10 +118,10 @@
             factory.container_title, factory.container_description)
 
-class IApplicantsRoot(IWAeUPObject, IContainer):
+class IApplicantsRoot(ISIRPObject, IContainer):
     """A container for university applicants containers.
     """
     pass
 
-class IApplicantsContainer(IWAeUPObject):
+class IApplicantsContainer(ISIRPObject):
     """An applicants container contains university applicants.
 
@@ -275,5 +275,5 @@
     'provider'].order =  IApplicantsContainer['provider'].order
 
-class IApplicantBaseData(IWAeUPObject):
+class IApplicantBaseData(ISIRPObject):
     """The data for an applicant.
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/root.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/root.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/root.py	(revision 7321)
@@ -23,5 +23,5 @@
 from hurry.query.interfaces import IQuery
 from zope.component import getUtility
-from waeup.sirp.interfaces import IWAeUPSIRPPluggable
+from waeup.sirp.interfaces import ISIRPPluggable
 from waeup.sirp.applicants.interfaces import IApplicantsRoot
 from waeup.sirp.utils.helpers import get_current_principal
@@ -49,5 +49,5 @@
 
 class ApplicantsPlugin(grok.GlobalUtility):
-    """A WAeUPSIRPPlugin that creates an applicants root in portal.
+    """A SIRPPlugin that creates an applicants root in portal.
 
     This plugin should be called by a typical
@@ -56,8 +56,8 @@
     the main site configuration.
 
-    Implements :class:`waeup.sirp.interfaces.IWAeUPSIRPPluggable`
+    Implements :class:`waeup.sirp.interfaces.ISIRPPluggable`
     """
     grok.name('applicants')
-    grok.implements(IWAeUPSIRPPluggable)
+    grok.implements(ISIRPPluggable)
     log_prefix = 'ApplicantsPlugin'
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_applicant.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_applicant.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/tests/test_applicant.py	(revision 7321)
@@ -26,5 +26,5 @@
 from zope.interface import verify, implements
 from zope.location.interfaces import ILocation
-from waeup.sirp.image.interfaces import IWAeUPImageFile
+from waeup.sirp.image.interfaces import ISIRPImageFile
 from waeup.sirp.imagestorage import DefaultStorage
 from waeup.sirp.interfaces import IFileStoreHandler, IFileStoreNameChooser
@@ -38,5 +38,5 @@
 class FakeImageLocation(object):
     implements(ILocation)
-    adapts(IWAeUPImageFile)
+    adapts(ISIRPImageFile)
     def __init__(self, context):
         pass
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/vocabularies.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/vocabularies.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/vocabularies.py	(revision 7321)
@@ -20,5 +20,5 @@
 from zope.component import getUtility
 from zope.catalog.interfaces import ICatalog
-from waeup.sirp.interfaces import SimpleWAeUPVocabulary
+from waeup.sirp.interfaces import SimpleSIRPVocabulary
 from waeup.sirp.students.vocabularies import CertificateSource
 
@@ -37,9 +37,9 @@
     )
 
-#: A :class:`waeup.sirp.interfaces.SimpleWAeUPVocabulary` of supported
+#: A :class:`waeup.sirp.interfaces.SimpleSIRPVocabulary` of supported
 #: application or screening types.
-application_types_vocab = SimpleWAeUPVocabulary(
+application_types_vocab = SimpleSIRPVocabulary(
     *[(x[0],x[1]) for x in APPLICATION_TYPES])
-application_pins_vocab = SimpleWAeUPVocabulary(
+application_pins_vocab = SimpleSIRPVocabulary(
     *[(u"%s (%s)" % (x[2],x[0]),x[2]) for x in APPLICATION_TYPES])
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/workflow.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/workflow.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/workflow.py	(revision 7321)
@@ -22,6 +22,6 @@
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
 from waeup.sirp.applicants.interfaces import IApplicantBaseData
-from waeup.sirp.interfaces import IObjectHistory, IWAeUPWorkflowInfo
-from waeup.sirp.workflow import WAeUPWorkflow, WAeUPWorkflowInfo
+from waeup.sirp.interfaces import IObjectHistory, ISIRPWorkflowInfo
+from waeup.sirp.workflow import SIRPWorkflow, SIRPWorkflowInfo
 from waeup.sirp.utils.helpers import get_current_principal
 
@@ -127,5 +127,5 @@
     )
 
-application_workflow = WAeUPWorkflow(APPLICATION_TRANSITIONS)
+application_workflow = SIRPWorkflow(APPLICATION_TRANSITIONS)
 
 class ApplicationWorkflowState(WorkflowState, grok.Adapter):
@@ -138,9 +138,9 @@
     state_id = 'wf.application.id'
 
-class ApplicationWorkflowInfo(WAeUPWorkflowInfo, grok.Adapter):
+class ApplicationWorkflowInfo(SIRPWorkflowInfo, grok.Adapter):
     """Adapter to adapt Applicant objects to workflow info objects.
     """
     grok.context(IApplicantBaseData)
-    grok.provides(IWAeUPWorkflowInfo)
+    grok.provides(ISIRPWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 7318)
+++ main/waeup.sirp/trunk/src/waeup/sirp/applicants/browser.py	(revision 7321)
@@ -34,5 +34,5 @@
 from reportlab.platypus.tables import TableStyle
 from waeup.sirp.browser import (
-    WAeUPPage, WAeUPEditFormPage, WAeUPAddFormPage, WAeUPDisplayFormPage)
+    SIRPPage, SIRPEditFormPage, SIRPAddFormPage, SIRPDisplayFormPage)
 from waeup.sirp.browser.breadcrumbs import Breadcrumb
 from waeup.sirp.browser.layout import NullValidator
@@ -41,5 +41,5 @@
 from waeup.sirp.browser.viewlets import ManageActionButton, PrimaryNavTab
 from waeup.sirp.interfaces import (
-    IWAeUPObject, ILocalRolesAssignable, IExtFileStore,
+    ISIRPObject, ILocalRolesAssignable, IExtFileStore,
     IFileStoreNameChooser, IPasswordValidator, IUserAccount)
 from waeup.sirp.permissions import get_users_with_local_roles
@@ -60,7 +60,7 @@
 from waeup.sirp.students.interfaces import IStudentsUtils
 
-grok.context(IWAeUPObject) # Make IWAeUPObject the default context
-
-class ApplicantsRootPage(WAeUPPage):
+grok.context(ISIRPObject) # Make ISIRPObject the default context
+
+class ApplicantsRootPage(SIRPPage):
     grok.context(IApplicantsRoot)
     grok.name('index')
@@ -81,5 +81,5 @@
     text = 'Manage application section'
 
-class ApplicantsRootManageFormPage(WAeUPEditFormPage):
+class ApplicantsRootManageFormPage(SIRPEditFormPage):
     grok.context(IApplicantsRoot)
     grok.name('manage')
@@ -151,5 +151,5 @@
         return del_local_roles(self,2,**data)
 
-class ApplicantsContainerAddFormPage(WAeUPAddFormPage):
+class ApplicantsContainerAddFormPage(SIRPAddFormPage):
     grok.context(IApplicantsRoot)
     grok.require('waeup.manageApplication')
@@ -229,5 +229,5 @@
     """Applicants tab in primary navigation.
     """
-    grok.context(IWAeUPObject)
+    grok.context(ISIRPObject)
     grok.order(3)
     grok.require('waeup.viewApplicantsTab')
@@ -273,5 +273,5 @@
         return self.view.application_url() + rel_link
 
-class ApplicantsContainerPage(WAeUPDisplayFormPage):
+class ApplicantsContainerPage(SIRPDisplayFormPage):
     """The standard view for regular applicant containers.
     """
@@ -311,5 +311,5 @@
 #    target = 'login'
 
-class ApplicantsContainerManageFormPage(WAeUPEditFormPage):
+class ApplicantsContainerManageFormPage(SIRPEditFormPage):
     grok.context(IApplicantsContainer)
     grok.name('manage')
@@ -404,5 +404,5 @@
         return del_local_roles(self,3,**data)
 
-class ApplicantAddFormPage(WAeUPAddFormPage):
+class ApplicantAddFormPage(SIRPAddFormPage):
     """Add-form to add an applicant.
     """
@@ -431,5 +431,5 @@
         return
 
-class ApplicantDisplayFormPage(WAeUPDisplayFormPage):
+class ApplicantDisplayFormPage(SIRPDisplayFormPage):
     grok.context(IApplicant)
     grok.name('index')
@@ -532,5 +532,5 @@
 
 
-class OnlinePaymentDisplayFormPage(WAeUPDisplayFormPage):
+class OnlinePaymentDisplayFormPage(SIRPDisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -700,5 +700,5 @@
         pdf.setAuthor('%s (%s)' % (self.request.principal.title,
             self.request.principal.id))
-        pdf.setCreator('WAeUP SIRP')
+        pdf.setCreator('SIRP SIRP')
         width, height = A4
         style = getSampleStyleSheet()
@@ -802,5 +802,5 @@
     return True
 
-class ApplicantManageFormPage(WAeUPEditFormPage):
+class ApplicantManageFormPage(SIRPEditFormPage):
     """A full edit view for applicant data.
     """